struct Fixes;Trait Implementations
Sourceimpl ObjectData for Fixes
impl ObjectData for Fixes
Sourcefn event(
self: Arc<Self>,
_backend: &Backend,
_msg: Message<ObjectId, OwnedFd>,
) -> Option<Arc<dyn ObjectData>>
fn event( self: Arc<Self>, _backend: &Backend, _msg: Message<ObjectId, OwnedFd>, ) -> Option<Arc<dyn ObjectData>>
Dispatch an event for the associated object Read more
Sourcefn destroyed(&self, _object_id: ObjectId)
fn destroyed(&self, _object_id: ObjectId)
Notification that the object has been destroyed and is no longer active
Sourcefn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Helper for forwarding a Debug implementation of your
ObjectData type Read moreSourcefn data_as_any(&self) -> &(dyn Any + 'static)
fn data_as_any(&self) -> &(dyn Any + 'static)
Helper for accessing user data Read more